@@ -26,7 +26,6 @@ import socket
 import subprocess
 import sys
 
-import six
 
 from monasca_setup import agent_config
 from monasca_setup.service.detection import detect_init
@@ -288,7 +287,7 @@ def parse_arguments(parser):
     parser.add_argument(
         '--monasca_url',
         help="Monasca API url, if not defined the url is pulled from keystone",
-        type=six.text_type,
+        type=str,
         default='')
     parser.add_argument(
         '--service_type',
@@ -442,7 +441,7 @@ def parse_arguments(parser):
                         help="Statsd metric aggregation interval (seconds)",
                         default=20)
     parser.add_argument('--agent_service_name',
-                        help="agent's systemd/sysv service name",
+                        help="systemd/sysv service name of agent",
                         required=False,
                         default='monasca-agent')
     parser.add_argument('--enable_logrotate', help="Controls log file rotation", default=True)
